# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.2.2
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, constr, validator
from authentik_client.models.policy_engine_mode import PolicyEngineMode
from authentik_client.models.provider_type_enum import ProviderTypeEnum
from authentik_client.models.user_matching_mode_enum import UserMatchingModeEnum

class OAuthSourceRequest(BaseModel):
    """
    OAuth Source Serializer  # noqa: E501
    """
    name: constr(strict=True, min_length=1) = Field(..., description="Source's display Name.")
    slug: constr(strict=True, max_length=50, min_length=1) = Field(..., description="Internal source name, used in URLs.")
    enabled: Optional[StrictBool] = None
    authentication_flow: Optional[StrictStr] = Field(None, description="Flow to use when authenticating existing users.")
    enrollment_flow: Optional[StrictStr] = Field(None, description="Flow to use when enrolling new users.")
    policy_engine_mode: Optional[PolicyEngineMode] = None
    user_matching_mode: Optional[UserMatchingModeEnum] = Field(None, description="How the source determines if an existing user should be authenticated or a new user enrolled.")
    user_path_template: Optional[constr(strict=True, min_length=1)] = None
    provider_type: ProviderTypeEnum = Field(...)
    request_token_url: Optional[constr(strict=True, max_length=255, min_length=1)] = Field(None, description="URL used to request the initial token. This URL is only required for OAuth 1.")
    authorization_url: Optional[constr(strict=True, max_length=255, min_length=1)] = Field(None, description="URL the user is redirect to to conest the flow.")
    access_token_url: Optional[constr(strict=True, max_length=255, min_length=1)] = Field(None, description="URL used by authentik to retrieve tokens.")
    profile_url: Optional[constr(strict=True, max_length=255, min_length=1)] = Field(None, description="URL used by authentik to get user information.")
    consumer_key: constr(strict=True, min_length=1) = Field(...)
    consumer_secret: constr(strict=True, min_length=1) = Field(...)
    additional_scopes: Optional[StrictStr] = None
    oidc_well_known_url: Optional[StrictStr] = None
    oidc_jwks_url: Optional[StrictStr] = None
    oidc_jwks: Optional[Any] = None
    __properties = ["name", "slug", "enabled", "authentication_flow", "enrollment_flow", "policy_engine_mode", "user_matching_mode", "user_path_template", "provider_type", "request_token_url", "authorization_url", "access_token_url", "profile_url", "consumer_key", "consumer_secret", "additional_scopes", "oidc_well_known_url", "oidc_jwks_url", "oidc_jwks"]

    @validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OAuthSourceRequest:
        """Create an instance of OAuthSourceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if authentication_flow (nullable) is None
        # and __fields_set__ contains the field
        if self.authentication_flow is None and "authentication_flow" in self.__fields_set__:
            _dict['authentication_flow'] = None

        # set to None if enrollment_flow (nullable) is None
        # and __fields_set__ contains the field
        if self.enrollment_flow is None and "enrollment_flow" in self.__fields_set__:
            _dict['enrollment_flow'] = None

        # set to None if request_token_url (nullable) is None
        # and __fields_set__ contains the field
        if self.request_token_url is None and "request_token_url" in self.__fields_set__:
            _dict['request_token_url'] = None

        # set to None if authorization_url (nullable) is None
        # and __fields_set__ contains the field
        if self.authorization_url is None and "authorization_url" in self.__fields_set__:
            _dict['authorization_url'] = None

        # set to None if access_token_url (nullable) is None
        # and __fields_set__ contains the field
        if self.access_token_url is None and "access_token_url" in self.__fields_set__:
            _dict['access_token_url'] = None

        # set to None if profile_url (nullable) is None
        # and __fields_set__ contains the field
        if self.profile_url is None and "profile_url" in self.__fields_set__:
            _dict['profile_url'] = None

        # set to None if oidc_jwks (nullable) is None
        # and __fields_set__ contains the field
        if self.oidc_jwks is None and "oidc_jwks" in self.__fields_set__:
            _dict['oidc_jwks'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OAuthSourceRequest:
        """Create an instance of OAuthSourceRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OAuthSourceRequest.parse_obj(obj)

        _obj = OAuthSourceRequest.parse_obj({
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "enabled": obj.get("enabled"),
            "authentication_flow": obj.get("authentication_flow"),
            "enrollment_flow": obj.get("enrollment_flow"),
            "policy_engine_mode": obj.get("policy_engine_mode"),
            "user_matching_mode": obj.get("user_matching_mode"),
            "user_path_template": obj.get("user_path_template"),
            "provider_type": obj.get("provider_type"),
            "request_token_url": obj.get("request_token_url"),
            "authorization_url": obj.get("authorization_url"),
            "access_token_url": obj.get("access_token_url"),
            "profile_url": obj.get("profile_url"),
            "consumer_key": obj.get("consumer_key"),
            "consumer_secret": obj.get("consumer_secret"),
            "additional_scopes": obj.get("additional_scopes"),
            "oidc_well_known_url": obj.get("oidc_well_known_url"),
            "oidc_jwks_url": obj.get("oidc_jwks_url"),
            "oidc_jwks": obj.get("oidc_jwks")
        })
        return _obj


