# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.2.2
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, constr, validator
from authentik_client.models.policy_engine_mode import PolicyEngineMode
from authentik_client.models.user_matching_mode_enum import UserMatchingModeEnum

class PlexSource(BaseModel):
    """
    Plex Source Serializer  # noqa: E501
    """
    pk: StrictStr = Field(...)
    name: StrictStr = Field(..., description="Source's display Name.")
    slug: constr(strict=True, max_length=50) = Field(..., description="Internal source name, used in URLs.")
    enabled: Optional[StrictBool] = None
    authentication_flow: Optional[StrictStr] = Field(None, description="Flow to use when authenticating existing users.")
    enrollment_flow: Optional[StrictStr] = Field(None, description="Flow to use when enrolling new users.")
    component: StrictStr = Field(..., description="Get object component so that we know how to edit the object")
    verbose_name: StrictStr = Field(..., description="Return object's verbose_name")
    verbose_name_plural: StrictStr = Field(..., description="Return object's plural verbose_name")
    meta_model_name: StrictStr = Field(..., description="Return internal model name")
    policy_engine_mode: Optional[PolicyEngineMode] = None
    user_matching_mode: Optional[UserMatchingModeEnum] = Field(None, description="How the source determines if an existing user should be authenticated or a new user enrolled.")
    managed: Optional[StrictStr] = Field(..., description="Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.")
    user_path_template: Optional[StrictStr] = None
    icon: Optional[StrictStr] = Field(..., description="Get the URL to the Icon. If the name is /static or starts with http it is returned as-is")
    client_id: Optional[StrictStr] = Field(None, description="Client identifier used to talk to Plex.")
    allowed_servers: Optional[conlist(StrictStr)] = Field(None, description="Which servers a user has to be a member of to be granted access. Empty list allows every server.")
    allow_friends: Optional[StrictBool] = Field(None, description="Allow friends to authenticate, even if you don't share a server.")
    plex_token: StrictStr = Field(..., description="Plex token used to check friends")
    __properties = ["pk", "name", "slug", "enabled", "authentication_flow", "enrollment_flow", "component", "verbose_name", "verbose_name_plural", "meta_model_name", "policy_engine_mode", "user_matching_mode", "managed", "user_path_template", "icon", "client_id", "allowed_servers", "allow_friends", "plex_token"]

    @validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PlexSource:
        """Create an instance of PlexSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "pk",
                            "component",
                            "verbose_name",
                            "verbose_name_plural",
                            "meta_model_name",
                            "managed",
                            "icon",
                          },
                          exclude_none=True)
        # set to None if authentication_flow (nullable) is None
        # and __fields_set__ contains the field
        if self.authentication_flow is None and "authentication_flow" in self.__fields_set__:
            _dict['authentication_flow'] = None

        # set to None if enrollment_flow (nullable) is None
        # and __fields_set__ contains the field
        if self.enrollment_flow is None and "enrollment_flow" in self.__fields_set__:
            _dict['enrollment_flow'] = None

        # set to None if managed (nullable) is None
        # and __fields_set__ contains the field
        if self.managed is None and "managed" in self.__fields_set__:
            _dict['managed'] = None

        # set to None if icon (nullable) is None
        # and __fields_set__ contains the field
        if self.icon is None and "icon" in self.__fields_set__:
            _dict['icon'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlexSource:
        """Create an instance of PlexSource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlexSource.parse_obj(obj)

        _obj = PlexSource.parse_obj({
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "enabled": obj.get("enabled"),
            "authentication_flow": obj.get("authentication_flow"),
            "enrollment_flow": obj.get("enrollment_flow"),
            "component": obj.get("component"),
            "verbose_name": obj.get("verbose_name"),
            "verbose_name_plural": obj.get("verbose_name_plural"),
            "meta_model_name": obj.get("meta_model_name"),
            "policy_engine_mode": obj.get("policy_engine_mode"),
            "user_matching_mode": obj.get("user_matching_mode"),
            "managed": obj.get("managed"),
            "user_path_template": obj.get("user_path_template"),
            "icon": obj.get("icon"),
            "client_id": obj.get("client_id"),
            "allowed_servers": obj.get("allowed_servers"),
            "allow_friends": obj.get("allow_friends"),
            "plex_token": obj.get("plex_token")
        })
        return _obj


